yakumo.nova.v2.availability_zone

Package yakumo :: Package nova :: Package v2 :: Module availability_zone |
[hide private]
[frames] | no frames]

# Module availability_zone

source code

Resource class and its manager for availability zones in Compute API v2

Classes | [hide private]
| Resource Resource class for availability zones in Compute API v2
| Manager Manager class for availability zones in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``name``'``,` `'``zoneName``'``,` <yakumo.mapper.NoopC`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('name',
        'zoneName',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('status',
        'zoneState',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('hosts',
        'hosts',
      ...